==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/StaticIPAMDNSFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StaticIPAMDNSFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<A>{
  public StaticIPAMDNSFluentImpl() {
  }
  public StaticIPAMDNSFluentImpl(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance) {
    this.withDomain(instance.getDomain()); 
    this.withNameservers(instance.getNameservers()); 
    this.withSearch(instance.getSearch()); 
  }
  private java.lang.String domain;
  private java.util.List<java.lang.String> nameservers = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> search = new java.util.ArrayList<java.lang.String>();
  public java.lang.String getDomain() {
    return this.domain;
  }
  public A withDomain(java.lang.String domain) {
    this.domain=domain; return (A) this;
  }
  public java.lang.Boolean hasDomain() {
    return this.domain != null;
  }
  
  /**
   * Method is deprecated. use withDomain instead.
   */
  @java.lang.Deprecated
  public A withNewDomain(java.lang.String arg0) {
    return (A)withDomain(new String(arg0));
  }
  public A addToNameservers(java.lang.Integer index,java.lang.String item) {
    if (this.nameservers == null) {this.nameservers = new java.util.ArrayList<java.lang.String>();}
    this.nameservers.add(index, item);
    return (A)this;
  }
  public A setToNameservers(java.lang.Integer index,java.lang.String item) {
    if (this.nameservers == null) {this.nameservers = new java.util.ArrayList<java.lang.String>();}
    this.nameservers.set(index, item); return (A)this;
  }
  public A addToNameservers(java.lang.String... items) {
    if (this.nameservers == null) {this.nameservers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.nameservers.add(item);} return (A)this;
  }
  public A addAllToNameservers(java.util.Collection<java.lang.String> items) {
    if (this.nameservers == null) {this.nameservers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.nameservers.add(item);} return (A)this;
  }
  public A removeFromNameservers(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.nameservers!= null){ this.nameservers.remove(item);}} return (A)this;
  }
  public A removeAllFromNameservers(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.nameservers!= null){ this.nameservers.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getNameservers() {
    return this.nameservers;
  }
  public java.lang.String getNameserver(java.lang.Integer index) {
    return this.nameservers.get(index);
  }
  public java.lang.String getFirstNameserver() {
    return this.nameservers.get(0);
  }
  public java.lang.String getLastNameserver() {
    return this.nameservers.get(nameservers.size() - 1);
  }
  public java.lang.String getMatchingNameserver(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: nameservers) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingNameserver(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: nameservers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNameservers(java.util.List<java.lang.String> nameservers) {
    if (nameservers != null) {this.nameservers = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : nameservers){this.addToNameservers(item);}} else { this.nameservers = null;} return (A) this;
  }
  public A withNameservers(java.lang.String... nameservers) {
    if (this.nameservers != null) {this.nameservers.clear();}
    if (nameservers != null) {for (java.lang.String item :nameservers){ this.addToNameservers(item);}} return (A) this;
  }
  public java.lang.Boolean hasNameservers() {
    return nameservers != null && !nameservers.isEmpty();
  }
  public A addNewNameserver(java.lang.String arg0) {
    return (A)addToNameservers(new String(arg0));
  }
  public A addToSearch(java.lang.Integer index,java.lang.String item) {
    if (this.search == null) {this.search = new java.util.ArrayList<java.lang.String>();}
    this.search.add(index, item);
    return (A)this;
  }
  public A setToSearch(java.lang.Integer index,java.lang.String item) {
    if (this.search == null) {this.search = new java.util.ArrayList<java.lang.String>();}
    this.search.set(index, item); return (A)this;
  }
  public A addToSearch(java.lang.String... items) {
    if (this.search == null) {this.search = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.search.add(item);} return (A)this;
  }
  public A addAllToSearch(java.util.Collection<java.lang.String> items) {
    if (this.search == null) {this.search = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.search.add(item);} return (A)this;
  }
  public A removeFromSearch(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.search!= null){ this.search.remove(item);}} return (A)this;
  }
  public A removeAllFromSearch(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.search!= null){ this.search.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSearch() {
    return this.search;
  }
  public java.lang.String getSearch(java.lang.Integer index) {
    return this.search.get(index);
  }
  public java.lang.String getFirstSearch() {
    return this.search.get(0);
  }
  public java.lang.String getLastSearch() {
    return this.search.get(search.size() - 1);
  }
  public java.lang.String getMatchingSearch(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: search) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSearch(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: search) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSearch(java.util.List<java.lang.String> search) {
    if (search != null) {this.search = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : search){this.addToSearch(item);}} else { this.search = null;} return (A) this;
  }
  public A withSearch(java.lang.String... search) {
    if (this.search != null) {this.search.clear();}
    if (search != null) {for (java.lang.String item :search){ this.addToSearch(item);}} return (A) this;
  }
  public java.lang.Boolean hasSearch() {
    return search != null && !search.isEmpty();
  }
  public A addNewSearch(java.lang.String arg0) {
    return (A)addToSearch(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StaticIPAMDNSFluentImpl that = (StaticIPAMDNSFluentImpl) o;
    if (domain != null ? !domain.equals(that.domain) :that.domain != null) return false;
    if (nameservers != null ? !nameservers.equals(that.nameservers) :that.nameservers != null) return false;
    if (search != null ? !search.equals(that.search) :that.search != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(domain,  nameservers,  search,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/StaticIPAMDNSFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StaticIPAMDNSFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<A>{
  public StaticIPAMDNSFluentImpl() {
  }
  public StaticIPAMDNSFluentImpl(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance) {
    this.withDomain(instance.getDomain()); 
    this.withNameservers(instance.getNameservers()); 
    this.withSearch(instance.getSearch()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String domain;
  private java.util.List<java.lang.String> nameservers = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> search = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDomain() {
    return this.domain;
  }
  public A withDomain(java.lang.String domain) {
    this.domain=domain; return (A) this;
  }
  public java.lang.Boolean hasDomain() {
    return this.domain != null;
  }
  
  /**
   * Method is deprecated. use withDomain instead.
   */
  @java.lang.Deprecated
  public A withNewDomain(java.lang.String arg0) {
    return (A)withDomain(new String(arg0));
  }
  public A addToNameservers(java.lang.Integer index,java.lang.String item) {
    if (this.nameservers == null) {this.nameservers = new java.util.ArrayList<java.lang.String>();}
    this.nameservers.add(index, item);
    return (A)this;
  }
  public A setToNameservers(java.lang.Integer index,java.lang.String item) {
    if (this.nameservers == null) {this.nameservers = new java.util.ArrayList<java.lang.String>();}
    this.nameservers.set(index, item); return (A)this;
  }
  public A addToNameservers(java.lang.String... items) {
    if (this.nameservers == null) {this.nameservers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.nameservers.add(item);} return (A)this;
  }
  public A addAllToNameservers(java.util.Collection<java.lang.String> items) {
    if (this.nameservers == null) {this.nameservers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.nameservers.add(item);} return (A)this;
  }
  public A removeFromNameservers(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.nameservers!= null){ this.nameservers.remove(item);}} return (A)this;
  }
  public A removeAllFromNameservers(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.nameservers!= null){ this.nameservers.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getNameservers() {
    return this.nameservers;
  }
  public java.lang.String getNameserver(java.lang.Integer index) {
    return this.nameservers.get(index);
  }
  public java.lang.String getFirstNameserver() {
    return this.nameservers.get(0);
  }
  public java.lang.String getLastNameserver() {
    return this.nameservers.get(nameservers.size() - 1);
  }
  public java.lang.String getMatchingNameserver(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: nameservers) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingNameserver(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: nameservers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNameservers(java.util.List<java.lang.String> nameservers) {
    if (nameservers != null) {this.nameservers = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : nameservers){this.addToNameservers(item);}} else { this.nameservers = null;} return (A) this;
  }
  public A withNameservers(java.lang.String... nameservers) {
    if (this.nameservers != null) {this.nameservers.clear();}
    if (nameservers != null) {for (java.lang.String item :nameservers){ this.addToNameservers(item);}} return (A) this;
  }
  public java.lang.Boolean hasNameservers() {
    return nameservers != null && !nameservers.isEmpty();
  }
  public A addNewNameserver(java.lang.String arg0) {
    return (A)addToNameservers(new String(arg0));
  }
  public A addToSearch(java.lang.Integer index,java.lang.String item) {
    if (this.search == null) {this.search = new java.util.ArrayList<java.lang.String>();}
    this.search.add(index, item);
    return (A)this;
  }
  public A setToSearch(java.lang.Integer index,java.lang.String item) {
    if (this.search == null) {this.search = new java.util.ArrayList<java.lang.String>();}
    this.search.set(index, item); return (A)this;
  }
  public A addToSearch(java.lang.String... items) {
    if (this.search == null) {this.search = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.search.add(item);} return (A)this;
  }
  public A addAllToSearch(java.util.Collection<java.lang.String> items) {
    if (this.search == null) {this.search = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.search.add(item);} return (A)this;
  }
  public A removeFromSearch(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.search!= null){ this.search.remove(item);}} return (A)this;
  }
  public A removeAllFromSearch(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.search!= null){ this.search.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSearch() {
    return this.search;
  }
  public java.lang.String getSearch(java.lang.Integer index) {
    return this.search.get(index);
  }
  public java.lang.String getFirstSearch() {
    return this.search.get(0);
  }
  public java.lang.String getLastSearch() {
    return this.search.get(search.size() - 1);
  }
  public java.lang.String getMatchingSearch(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: search) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSearch(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: search) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSearch(java.util.List<java.lang.String> search) {
    if (search != null) {this.search = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : search){this.addToSearch(item);}} else { this.search = null;} return (A) this;
  }
  public A withSearch(java.lang.String... search) {
    if (this.search != null) {this.search.clear();}
    if (search != null) {for (java.lang.String item :search){ this.addToSearch(item);}} return (A) this;
  }
  public java.lang.Boolean hasSearch() {
    return search != null && !search.isEmpty();
  }
  public A addNewSearch(java.lang.String arg0) {
    return (A)addToSearch(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StaticIPAMDNSFluentImpl that = (StaticIPAMDNSFluentImpl) o;
    if (domain != null ? !domain.equals(that.domain) :that.domain != null) return false;
    if (nameservers != null ? !nameservers.equals(that.nameservers) :that.nameservers != null) return false;
    if (search != null ? !search.equals(that.search) :that.search != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(domain,  nameservers,  search,  additionalProperties,  super.hashCode());
  }
  
}
